@@ -369,6 +369,7 @@ class DeltaBot:
             # set some useful bot defaults on the account
             delete_server_after=1,
             delete_device_after=2592000,
+            save_mime_headers=1,
             e2ee_enabled=1,
             sentbox_watch=0,
             mvbox_move=0,
@@ -507,6 +508,9 @@ class CheckAll:
                 )
             )
             can_encrypt = encrinfo.splitlines()[0].lower() != "no encryption."
+            can_encrypt = can_encrypt or "Chat-Version" not in (
+                message.get_mime_headers() or dict()
+            )
         else:
             can_encrypt = True
         if message.is_encrypted() or can_encrypt:
@@ -545,8 +549,8 @@ class CheckAll:
             )
             return
 
-        res = parse_system_title_changed(message.text, message.chat.get_name())
-        if res is not None:
+        res = parse_system_title_changed(message.text)
+        if res:
             old_title, actor = res
             logger.debug("calling hook deltabot_title_changed")
             self.bot.plugins.hook.deltabot_title_changed(
@@ -612,8 +616,7 @@ class IncomingEventHandler:
 
     @account_hookimpl
     def ac_incoming_message(self, message: Message) -> None:
-        # we always accept incoming messages to remove the need  for
-        # bot authors to having to deal with deaddrop/contact requests.
+        # accept contact request, just in case "bot" setting is disabled
         message.create_chat()
         self.logger.debug(
             f"incoming message from {message.get_sender_contact().addr} id={message.id} chat={message.chat.id} text={message.text[:50]!r}"
